#
# spec file for package roaraudio
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 2
%define pkg_version 1.0beta11
Name:           roaraudio
Version:        0.99+1.0beta11
Release:        lp150.3.7
Summary:        Sound server for audio mixin
License:        GPL-3.0+ and LGPL-3.0+
Group:          System/Sound Daemons
Url:            http://%{name}.keep-cool.org/
Source:         %{name}-%{pkg_version}.tar.xz
Source1:        %{name}.conf
Source2:        %{name}.service
Source3:        %{name}-tmpfile.conf
Patch0:         roaraudio.buildtime.patch
Patch1:         roaraudio.stdio.patch
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  kernel-devel
BuildRequires:  libdnet-devel
BuildRequires:  make
#BuildRequires:  openslp-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(ao)
#BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(oggz)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(rsound)
BuildRequires:  pkgconfig(shout)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(speexdsp)
BuildRequires:  pkgconfig(vorbis)
#BuildRequires:  pkgconfig(x11)
Recommends:     %{name}-plugins
Recommends:     savannahice
Provides:       roaraudio-server
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(pre):  coreutils
Requires(pre):  shadow
%if 0%{?suse_version} > 1320
Requires(pre):  system-group-hardware
%endif
Requires(pre):  util-linux-systemd
BuildRequires:  systemd
%{!?_tmpfilesdir:%global _tmpfilesdir %{_libexecdir}/tmpfiles.d}
%{?systemd_requires}

%description
RoarAudio is a modern, multi OS sound system. Its main purpose is to
connect software (like media players) and devices (like soundcards) as a
mid-layer adding features you expect from a modern sound system like
software mixing and full network transparency.

RoarAudio can also be used to connect multiple software components. An
example for such a setup is a common webradio setup where the used playback
software is connected to a streaming server in addition to a local
soundcard. RoarAudio has special features for such setups like meta data
passing.

%package -n     libroar%{soname}
Summary:        Libraries for the RoarAudio sound server
Group:          System/Libraries

%description -n libroar%{soname}
Sound server for audio mixing.
...
Central library used to comunicate with RoarAudio servers. It supports all
commands from simple commands to play some audio up to complex commands to
controll the server and do nice things over the network.

This package of libraries which used by most applications implementing
RoarAudio support for example by media players.

%package        plugins
Summary:        Collection of plugins for libroar
Group:          System/Sound Daemons
Requires:       %{name} = %{version}

%description 	plugins
Sound server for audio mixing.
...
Collection of plugins which can be loaded in all host applications (e.g.
roard, roarpluginrunner and etc).

%package        compat%{soname}
Summary:        Compatibility layers
Group:          System/Sound Daemons
Requires:       libroar%{soname} = %{version}

%description 	compat%{soname}
Sound server for audio mixing.
...
Roarify is a loader for the compatibility layers. Those are layers which
are placed (by roarify) between a application and libroar to enable the
application to use RoarAudio even if it's not supported natively. Those
layers emulate oher sound systems. This is not a OSS emulation like most
other sound systems have it but a much more complet emulation which allowes
nearly every audio using application to use RoarAudio.

%package -n 	roar-devel
Summary:        Development Environment for the RoarAudio Sound System
Group:          Development/Libraries/C and C++
#Requires:  	openslp-devel
Requires:  		pkgconfig
Requires:       %{name}-compat%{soname} = %{version}
Provides:       %{name}-devel = %{version}

%description -n roar-devel
RoarAudio is a modern, multi OS sound system. Its main purpose is to
connect software (like media players) and devices (like soundcards) as a
mid-layer adding features you expect from a modern sound system like
software mixing and full network transparency.

RoarAudio can also be used to connect multiple software components. An
example for such a setup is a common webradio setup where the used playback
software is connected to a streaming server in addition to a local
soundcard. RoarAudio has special features for such setups like meta data
passing.

%prep
%autosetup -p1 -n "%{name}-%{pkg_version}"

%build
./configure \
    --cflags "%{optflags} -fno-strict-aliasing -D_LARGEFILE64_SOURCE" \
    --cc "gcc" \
    --cdrom /dev/cdrom \
    --audio-group audio \
    --runtime-detect \
    --prefix "%{_prefix}" \
    --prefix-lib "%{_libdir}" \
    --prefix-man "%{_mandir}" \
    --default-rate 44100 \
    --without-beta \
    --without-memory-api

make %{?_smp_m_flags} \
    OPTI_O="%{optflags} -fno-strict-aliasing -D_LARGEFILE64_SOURCE " \
    CC="gcc"

%install
%make_install

install -d %{buildroot}/%{_sbindir}
install -Dm 644 %{S:1} %{buildroot}%{_sysconfdir}/%{name}/roard.conf
install -Dm 644 %{S:2} %{buildroot}%{_unitdir}/roard.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcroard
install -Dm 644 %{S:3} %{buildroot}%{_tmpfilesdir}/%{name}.conf

for l in artsc Y2; do
    rm -fv "%{buildroot}%{_libdir}/%{name}/complibs/lib${l}".*
done

%fdupes -s %{buildroot}/%{_mandir}

%pre
%service_add_pre roard.service
if ! /usr/bin/id roard &>/dev/null; then
/usr/sbin/useradd -r -g audio -d /var/lib/roard roard || \
logger "Unexpected error adding user \"roard\". Aborting installation."
if test ! -d /var/lib/roard; then
install -d -m0750 -oroard -gaudio /var/lib/roard; fi
fi

%post
%service_add_post roard.service
systemd-tmpfiles --create %{_libexecdir}/tmpfiles.d/%{name}.conf

%preun
%service_del_preun roard.service

%postun
%service_del_postun roard.service
if [ $1 -eq 0 ]; then
userdel roard || logger "User \"roard\" could not be deleted."
rm -rf /var/lib/roard; fi

%post   -n libroar%{soname} -p /sbin/ldconfig

%postun -n libroar%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING* HACKING README TODO
%{_bindir}/roard
%{_bindir}/roarbidir
%{_bindir}/roarcat
%{_bindir}/roarcatplay
%{_bindir}/roarcatvio
%{_bindir}/roarclientpass
%{_bindir}/roarctl
%{_bindir}/roardtmf
%{_bindir}/roarfilt
%{_bindir}/roarinterconnect
%{_bindir}/roarlight
%{_bindir}/roarmon
%{_bindir}/roarmonhttp
%{_bindir}/roarphone
%{_bindir}/roarpluginapplication
%{_bindir}/roarpluginrunner
%{_bindir}/roarradio
%{_bindir}/roarshout
%{_bindir}/roarsin
%{_bindir}/roarvio
%{_bindir}/roarvorbis
%{_bindir}/roarvumeter
%{_mandir}/man1/roard.1*
%{_mandir}/man1/roar*.1.*
%{_sbindir}/rcroard
%{_unitdir}/roard.service
%{_tmpfilesdir}/%{name}.conf
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/roard.conf
%exclude %{_mandir}/man1/roar-config.1.*
%exclude %{_mandir}/man1/roarsockconnect.1.*
%exclude %{_mandir}/man1/roartypes.1.*
%exclude %{_mandir}/man1/roarify.1.*

%files -n libroar%{soname}
%defattr(-,root,root)
%{_libdir}/libroar*.so.%{soname}

%files plugins
%defattr(-,root,root)
%{_libdir}/%{name}/plugins

%files compat%{soname}
%defattr(-,root,root)
%{_bindir}/roarify
%{_libdir}/%{name}/compbins
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/complibs
%{_libdir}/%{name}/complibs/*.so.*
%{_mandir}/man1/roarify.1.*

%files -n roar-devel
%defattr(-,root,root)
%{_bindir}/roar-config
%{_bindir}/roarsockconnect
%{_bindir}/roartypes
%{_includedir}/%{name}.h
%{_includedir}/%{name}
%{_includedir}/libroar*
%{_libdir}/libroar*.so
%{_libdir}/ckport
%{_libdir}/%{name}/complibs/*.so
%dir %{_libdir}/%{name}/build-system
%{_libdir}/%{name}/build-system
%{_libdir}/pkgconfig/libroar*.pc
%{_mandir}/man1/roar-config.1.*
%{_mandir}/man1/roarsockconnect.1.*
%{_mandir}/man1/roartypes.1.*
%{_mandir}/man3/roar_*.3.*
%{_mandir}/man7/RoarAudio.7.*
%{_mandir}/man7/libroar.7.*
%{_mandir}/man7/roar*.7.*

%changelog
* Thu May 28 2015 avvissu@yandex.ru
- Remove Provides: roaraudio
- Create roard directory after installation
- Change roaraudio-tmpfile.conf: create a directory if only it does
  not exist.
* Tue May  5 2015 avvissu@yandex.ru
- Add Provides: roaraudio-server
* Fri May  1 2015 avvissu@yandex.ru
- Remove the home directory of user roard:
  * rm -rf /var/lib/roard (see: roarpld.service of package roarpld)
- Create roaraudio.conf into tmpfiles.d
- Add Recommends: roaraudio-plugins savannahice
* Tue Apr 28 2015 avvissu@yandex.ru
- Fix build on openSUSE > 13.2:
  * use pkgconfig in package names
- Add additional functions for configuration:
  * do not use internal memory API
  * disable beta code
- Installed a native systemd service file:
  * add roaraudio.service
  * add roaraudio.conf
- Add packages: libroar, plugins, compat
- Change the list of files for packages
- Use fdupes to find duplicate files
- Spec file cleanup
* Mon Oct 13 2014 olaf@aepfle.de
- Update to beta11
* Thu Jul 19 2012 pascal.bleser@opensuse.org
- don't build against celt on 12.2 either, too old too (or too recent), breaks
* Thu Jul 19 2012 pascal.bleser@opensuse.org
- initial version (0.99+1.0beta2)
